#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-FmuLsIXssY60NmJZFcyM6
key:                  http-download-0.2.1.0-FmuLsIXssY60NmJZFcyM6
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  7fe3ba0012a518a058ab87ba1d02ee99
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-FmuLsIXssY60NmJZFcyM6
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-1NArAo3cNK0LoUlrXpNy9J
    bytestring-0.11.5.3 conduit-1.3.6.1-7ztpQFzxkQu9fYslJzAtaH
    conduit-extra-1.3.8-EtHHdCy2JFLEIdUwh75e4q
    crypton-1.0.4-I0bzTn2woJ4DLB7BtNhDWv
    crypton-conduit-0.2.3-FLZcXJD1bNv6gJ3BXLdbSt directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-KIsPCwAmJfj40FXZ7rXqbo
    http-conduit-2.3.9.1-9vgkevnzuZMGmzJ8MF8Wc0
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-IRE5PLEtTguLTbdZl0KbOt
    path-io-1.8.2-BW9d0e4Xzlu5wBy0j6qIO6
    retry-0.9.3.1-8ew4mK8R73R5HIgqyODUvJ
    rio-0.1.24.0-E9Vj8Tqnt8kFAbCMmmpasN
    rio-prettyprint-0.1.8.0-AOrQgMfDHlYC7wdZXXNN8C

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

